/*
 *  Main authors:
 *     Fabio Rossi <rossi@dmi.unipg.it>
 *
 *  Contributing authors:
 *     Stefano Bistarelli <bista@dmi.unipg.it>
 *     Francesco Santini <francesco.santini@dmi.unipg.it>
 *
 *  Copyright:
 *     Fabio Rossi, 2015
 *     Stefano Bistarelli, 2015
 *     Francesco Santini, 2015
 *
 * Last modified: Sep 20th, 2017
 *
 *  This file is part of ConArg Project, a software for Argumentation Framework:
 *     http://www.dmi.unipg.it/conarg
 *
 *  Permission is hereby granted, free of charge, to any person obtaining
 *  a copy of this software and associated documentation files (the
 *  "Software"), to deal in the Software without restriction, including
 *  without limitation the rights to use, copy, modify, merge, publish,
 *  distribute, sublicense, and/or sell copies of the Software, and to
 *  permit persons to whom the Software is furnished to do so, subject to
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 *  LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 *  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 *  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef TSOLUTION_H_
#define TSOLUTION_H_

struct tSolution {
	long lArgsSize;
	bool *pArgs;
	double dCost;
	tSolution(long lArgsCount) {
		lArgsSize = lArgsCount;
		pArgs = new bool[lArgsCount];
		dCost = -1;
	}
	~tSolution() {
		if(pArgs) {
			delete pArgs;
			pArgs = NULL;
		}
	}
	tSolution &operator=(const tSolution &other) {
		if(this != &other) {
			lArgsSize = other.lArgsSize;
			for(long i = 0L; i < lArgsSize; i++)
				pArgs[i] = other.pArgs[i];
			dCost = other.dCost;
		}
		return *this;
	}
	void SetEmptySolution(double d) {
		for(long i = 0L; i < lArgsSize; i++)
			pArgs[i] = 0L;
		dCost = d;
	}
	long GetSolCard() {
		long lRetCount = 0L;
		for(long l = 0L; l < lArgsSize; l++)
			if(pArgs[l])
				lRetCount++;
		return lRetCount;
	}
};
#endif /* TSOLUTION_H_ */
